Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: chrome/browser/profiles/profile_statistics_common.h

Issue 2915053002: Replace profile statistics preference count with AutofillCounter (Closed)
Patch Set: change to SetBooleanWithoutPathExpansion Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile_statistics_common.h
diff --git a/chrome/browser/profiles/profile_statistics_common.h b/chrome/browser/profiles/profile_statistics_common.h
index 5fad9cc49a95b104219087e3f4084e3db8f3f80c..0ea75b96e2e62f2ff357a527f5746dd89e0a2139 100644
--- a/chrome/browser/profiles/profile_statistics_common.h
+++ b/chrome/browser/profiles/profile_statistics_common.h
@@ -16,18 +16,16 @@ namespace profiles {
extern const char kProfileStatisticsBrowsingHistory[];
extern const char kProfileStatisticsPasswords[];
extern const char kProfileStatisticsBookmarks[];
-extern const char kProfileStatisticsSettings[];
+extern const char kProfileStatisticsAutofill[];
extern const std::array<const char*, 4> kProfileStatisticsCategories;
// Definition of a single return value of |ProfileStatisticsCallback|. If
// |success| is false, the statistics failed to load and |count| is undefined.
// The data look like these: {"BrowsingHistory", 912, true},
// {"Passwords", 71, true}, {"Bookmarks", 120, true}, {"Settings", 200, true}
struct ProfileCategoryStat {
std::string category;
int count;
- bool success;
};
// Definition of the return value of |ProfileStatisticsCallback|.
« no previous file with comments | « chrome/browser/profiles/profile_statistics_browsertest.cc ('k') | chrome/browser/profiles/profile_statistics_common.cc » ('j') | no next file with comments »
@@ -16,18 +16,16 @@ namespace profiles {
extern const std::array<const char*, 4> kProfileStatisticsCategories;
-// Definition of a single return value of |ProfileStatisticsCallback|. If
-// |success| is false, the statistics failed to load and |count| is undefined.
-// The data look like these: {"BrowsingHistory", 912, true},
-// {"Passwords", 71, true}, {"Bookmarks", 120, true}, {"Settings", 200, true}
+// Definition of a single return value of |ProfileStatisticsCallback|.
+// The data look like these: {"BrowsingHistory", 912},
+// {"Passwords", 71}, {"Bookmarks", 120}, {"Autofill", 200}.
struct ProfileCategoryStat {
std::string category;

Powered by Google App Engine
This is Rietveld 408576698